@@ -73,12 +73,12 @@ def pass_log_example():
     logs = [r for r in result]
     print("Excecution time: ", time() - start)
     print(len(logs))
-    # pprint(logs)
+    pprint(logs)
 
 
 if __name__ == "__main__":
     # Uncomment the example you want to run.
-    slow_control_example()
+    # slow_control_example()
     # tcs_trace_example()
-    # pass_log_example()
+    pass_log_example()
     pass
